lidarwind.filters.SecondTripEchoFilter
======================================

.. currentmodule:: lidarwind.filters

.. autoclass:: SecondTripEchoFilter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SecondTripEchoFilter.__init__
      ~SecondTripEchoFilter.cal_mean_and_anom_90
      ~SecondTripEchoFilter.cal_mean_and_anom_slant
      ~SecondTripEchoFilter.cleaning
      ~SecondTripEchoFilter.cleaning90
      ~SecondTripEchoFilter.get_time_edges
   
   

   
   
   